<?php
/**
 * Enqueue CSS and JS for admin area.
 */
function senpai_software_2fa_css_js(){
    // loading css
    wp_register_style( 'senpai-software-2fa-admin', plugin_dir_url( __DIR__ ) . 'css/senpai-software-2fa.css', false);
    wp_enqueue_style( 'senpai-software-2fa-admin' );

    // loading js
    wp_register_script( 'senpai-software-2fa-admin', plugin_dir_url( __DIR__ ).'js/senpai-software-2fa.js',false );
    wp_enqueue_script( 'senpai-software-2fa-admin' );
}
add_action( 'admin_enqueue_scripts', 'senpai_software_2fa_css_js' );

/**
 * Display user profile fields.
 */
function senpai_software_2fa_profile_fields($user){

    $user_id = $user->ID;
    $hash = get_user_meta($user_id, 'senpai_software_2fa_hash', true);
    $status = get_user_meta($user_id, 'senpai_software_2fa_status', true);

    $checked_disable=null;
    $checked_enable=null;

    if($status=="disable"){
        $checked_disable="checked";
    } elseif ($status=="enable"){
        $checked_enable="checked";
    }

    if(empty($hash)){
        $file_hash_text=__( 'Select your file','senpai-software-2fa' );
    } else {
        $file_hash_text=__( 'The file key has been accepted, but you can update it','senpai-software-2fa' );
    }
    ?>
    <div id="keyfile_block">
        <h3><?php echo esc_html(__( 'Two-factor authentication with a key file','senpai-software-2fa' )); ?></h3>
        <p><?php echo esc_html(__( 'You can select any file on your computer and use it as a secret key to log into the admin area. Your file will not be uploaded to the site.','senpai-software-2fa' )); ?></p>
        <table class="form-table">
            <tbody>
            <tr>
                <th><?php echo esc_html(__( 'Status','senpai-software-2fa' )); ?></th>
                <td>
                    <input type="radio" <?php echo esc_html($checked_disable); ?> id="senpai_software_2fa_status_disable"
                           name="senpai_software_2fa_status" value="disable">
                    <label for="senpai_software_2fa_status_disable"><?php echo esc_html(__( 'Disable','senpai-software-2fa' )); ?></label>
                    <input type="radio" <?php echo esc_html($checked_enable); ?> id="senpai_software_2fa_status_enable"
                           name="senpai_software_2fa_status" value="enable">
                    <label for="senpai_software_2fa_status_enable"><?php echo esc_html(__( 'Enable','senpai-software-2fa' )); ?></label>
                </td>
            </tr>
            <tr>
                <th><?php echo esc_html($file_hash_text); ?></th>
                <td>
                    <div id="senpai_software_2fa_block">
                        <p>
                        <label>
                            <span class="dashicons dashicons-admin-network"></span> <?php echo esc_html(__( 'Select key file (max file size 1 GB)','senpai-software-2fa' )); ?>
                            <input type="file" id="senpai_software_2fa_file" onchange="senpai_software_2fa_upload();">
                        </label>
                        <input type="hidden" id="senpai_software_2fa_hash" name="senpai_software_2fa_hash">
                        </p>
                        <p id="senpai_software_2fa_name"></p>
                        <p id="senpai_software_2fa_progress"></p>
                        <p id="senpai_software_2fa_error"><?php echo esc_html(__( 'File is too big','senpai-software-2fa' )); ?></p>
                    </div>
                </td>
            </tr>
            </tbody>
        </table>
        <p><span class="dashicons dashicons-warning"></span> <?php echo esc_html(__('Do not change the contents of the file that is used as the key.','senpai-software-2fa')); ?></p>
    </div>
    <?php
}
add_action('show_user_profile', 'senpai_software_2fa_profile_fields');
add_action('edit_user_profile', 'senpai_software_2fa_profile_fields');

/**
 * Update user profile fields.
 */
function senpai_software_2fa_profile_fields_save($user_id){

    if (!current_user_can('edit_user', $user_id)) {
        return false;
    }

    if(isset($_POST['senpai_software_2fa_status'])) {

        $status = sanitize_text_field( $_POST['senpai_software_2fa_status'] ); // Sanitized

        if ($status == 'enable' || $status == 'disable'){ // Validated
            update_user_meta($user_id, 'senpai_software_2fa_status', $status);
        }
    }

    if (isset($_POST['senpai_software_2fa_hash'])) {

        $file_hash = sanitize_text_field( $_POST['senpai_software_2fa_hash'] ); // Sanitized

        if ( preg_match( '/^[a-f0-9]{40}$/', $file_hash ) ) { // Validated
            $file_hash=sha1($file_hash);
            update_user_meta($user_id, 'senpai_software_2fa_hash', $file_hash);
        }
    }
}
add_action('personal_options_update', 'senpai_software_2fa_profile_fields_save');
add_action('edit_user_profile_update', 'senpai_software_2fa_profile_fields_save');