<?php
/**
 * Load CSS and JS files for login page
 */
function senpai_software_2fa_login_css_js() {
    // Load CSS
    wp_register_style( 'senpai-software-2fa', plugin_dir_url( __FILE__ ) . 'css/senpai-software-2fa.css', false );
    wp_enqueue_style( 'senpai-software-2fa' );

    // Load JS
    wp_register_script( 'senpai-software-2fa', plugin_dir_url( __FILE__ ) . 'js/senpai-software-2fa.js', false );
    wp_enqueue_script( 'senpai-software-2fa' );
}
add_action( 'login_enqueue_scripts', 'senpai_software_2fa_login_css_js' );

/**
 * Add form field for uploading key file
 */
function senpai_software_2fa_form_field() {
    ?>
    <div id="senpai_software_2fa_block">
        <p>
            <label>
                <span class="dashicons dashicons-admin-network"></span> <?php echo esc_html(__( 'Select key file','senpai-software-2fa' )); ?>
                <input type="file" id="senpai_software_2fa_file" onchange="senpai_software_2fa_upload();">
            </label>
            <input type="hidden" id="senpai_software_2fa_hash" name="senpai_software_2fa_hash">
        </p>
        <p id="senpai_software_2fa_name"></p>
        <p id="senpai_software_2fa_progress"></p>
        <p id="senpai_software_2fa_error"><?php echo esc_html(__( 'File is too big','senpai-software-2fa' )); ?></p>
    </div>
    <?php
}
add_action( 'login_form', 'senpai_software_2fa_form_field' );

/**
 * Validate key file
 */
function senpai_software_2fa_validation( $user, $password ) {
    $status = get_user_meta( $user->ID, 'senpai_software_2fa_status', true );
    $db_hash = get_user_meta( $user->ID, 'senpai_software_2fa_hash', true );
    if ( $status == 'enable' ) {
        if( isset( $_POST['senpai_software_2fa_hash'] ) && !empty($_POST['senpai_software_2fa_hash']) ){

            $file_hash = sanitize_text_field($_POST['senpai_software_2fa_hash']); // Sanitized

            if ( preg_match( '/^[a-f0-9]{40}$/', $file_hash ) ) { // Validated

                $file_hash=sha1($file_hash);

                if ($db_hash !== $file_hash) {
                    return new WP_Error('access denied', __('Wrong key file','senpai-software-2fa'));
                }
            } else {
                return new WP_Error('access denied', __('File error','senpai-software-2fa'));
            }
        } else {
            return new WP_Error( 'access denied', __( 'Upload your key file','senpai-software-2fa' ) );
        }
    }
    return $user;
}
add_action( 'wp_authenticate_user', 'senpai_software_2fa_validation', 10, 3 );